@@ -9,7 +9,7 @@ from subprocess import PIPE, Popen
 from rich.console import Console
 
 
-def subproc(commands=[], **kwargs):
+def subproc(commands: list, **kwargs):
     """
     Takes a list of BASH commands to run in a subprocess sequentially.
     Optional keyword arguments:
@@ -28,7 +28,7 @@ def subproc(commands=[], **kwargs):
     quiet = kwargs.pop('quiet', False)
 
     if spinner:
-        # we don't actually need this if we're not doing a progress spinner
+        # only need this if we're doing a progress spinner
         console = Console()
 
     status_line = "[bold green]♥ Running command[/bold green]"
@@ -51,7 +51,7 @@ def subproc(commands=[], **kwargs):
         return output
 
 
-def run_subprocess(command, **kwargs):
+def run_subprocess(command: str, **kwargs):
     """
     Takes a str commmand to run in BASH in a subprocess.
     Typically run from subproc, which handles output printing.
@@ -64,6 +64,8 @@ def run_subprocess(command, **kwargs):
     """
     # subprocess expects a list if there are spaces in the command
     cmd = command.split()
+    log.debug(cmd)
+    log.debug(kwargs)
 
     error_ok = False
     if 'error_ok' in kwargs:
@@ -74,6 +76,7 @@ def run_subprocess(command, **kwargs):
 
     ret_code = p.returncode
     res = p.communicate()
+    log.debug(res)
     res_stdout = res[0].decode('UTF-8')
     res_stderr = res[1].decode('UTF-8')
 
@@ -81,7 +84,7 @@ def run_subprocess(command, **kwargs):
         # check return code, raise error if failure
         if not ret_code:
             if res_stderr:
-                log.debug(res_stderr, extra={"markup": True})
+                log.debug(res_stderr)
         else:
             if ret_code != 0:
                 # also scan both stdout and stdin for weird errors
